@@ -1,6 +1,5 @@
-from django.utils.datastructures import SortedDict
 import re
-from ..exceptions import AlreadyRegistered, InvalidCondition, NoMatchingSettings
+from ..exceptions import InvalidCondition, NoMatchingSettings
 from . import checks
 
 
@@ -9,7 +8,7 @@ class NoSwitcher:
     pass
 
 
-class Switcher(object):
+class BaseSwitcher(object):
     checks = {}
 
     def __init__(self):
@@ -30,12 +29,14 @@ class Switcher(object):
                 return False
         return True
 
-    def register(self, settings_class=NoSwitcher, *simple_checks, **conditions):
+    def register(self, settings_class=NoSwitcher, *simple_checks,
+                 **conditions):
         """
         Register a settings class with the switcher. Can be passed the settings
         class to register or be used as a decorator.
 
-        :param settings_class: The class to register with the provided conditions.
+        :param settings_class: The class to register with the provided
+                conditions.
         :param *simple_checks: A list of conditions for using the settings
                 class. If any of the values are falsy, the class will not be
                 used. If any of the values are callable, they will be called
@@ -53,8 +54,8 @@ class Switcher(object):
         available_checks = self.checks.keys()
         for condition in conditions.keys():
             if condition not in available_checks:
-                raise InvalidCondition('There is no check for the condition'
-                        ' "%s"' % condition)
+                raise InvalidCondition(
+                    'There is no check for the condition "%s"' % condition)
 
         self._registry.append((settings_class, simple_checks, conditions))
 
@@ -67,12 +68,18 @@ class Switcher(object):
             if self.evaluate_conditions(simple_checks, conditions):
                 return settings_class()
         raise NoMatchingSettings('No settings classes matched the curent'
-                ' environment.')
+                                 ' environment.')
+
+
+class Switcher(BaseSwitcher):
+    def __init__(self):
+        super(Switcher, self).__init__()
+
+        # Add the default checks.
+        for k, v in vars(checks).items():
+            match = re.match(r'^check_(\w+)$', k)
+            if match and callable(v):
+                self.add_check(match.group(1), v)
 
 
 switcher = Switcher()
-
-for k, v in vars(checks).items():
-    match = re.match(r'^check_(\w+)$', k)
-    if match and callable(v):
-        switcher.add_check(match.group(1), v)
