@@ -4,7 +4,8 @@ from .utils import load_settings
 
 def test_load():
     """
-    Test that class based settings can be loading (and also verify that our method of unloading settings is working!)
+    Test that class based settings can be loading (and also verify that our
+    method of unloading settings is working!)
 
     """
     settings = load_settings('tests.settings.A')
@@ -31,3 +32,9 @@ def test_attr_access():
     parent_name, module_name = settings.SETTINGS_MODULE.rsplit('.', 1)
     parent = __import__(parent_name, fromlist=[''])
     getattr(parent, module_name)
+
+
+def test_reload():
+    settings = load_settings('tests.settings.A')
+    module = __import__(settings.SETTINGS_MODULE, fromlist=[''])
+    reload(module)
